@@ -4,6 +4,7 @@ from django.contrib.auth.models import User
 from django.db import models
 from django.utils.translation import gettext_lazy as _
 
+from .category import Category
 from .survey import Survey
 
 try:
@@ -27,6 +28,8 @@ class Response(models.Model):
     created = models.DateTimeField(_("Creation date"), auto_now_add=True)
     updated = models.DateTimeField(_("Update date"), auto_now=True)
     survey = models.ForeignKey(Survey, on_delete=models.CASCADE, verbose_name=_("Survey"), related_name="responses")
+    category = models.ForeignKey(Category, on_delete=models.CASCADE, verbose_name=_("Category"),
+                                 related_name="responses", blank=True, null=True)
     user = models.ForeignKey(user_model, on_delete=models.SET_NULL, verbose_name=_("User"), null=True, blank=True)
     interview_uuid = models.CharField(_("Interview unique identifier"), max_length=36)
     random_seed = models.IntegerField(null=True, blank=True)
